==> android-2.3.3-sources.jar: android/widget/ProgressBar.java <==
package android.widget;
@android.widget.RemoteViews.RemoteView()
public class ProgressBar
  extends android.view.View
{
public  ProgressBar(android.content.Context context) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
public  ProgressBar(android.content.Context context, android.util.AttributeSet attrs) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
public  ProgressBar(android.content.Context context, android.util.AttributeSet attrs, int defStyle) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
public synchronized  boolean isIndeterminate() { throw new RuntimeException("Stub!"); }
public synchronized  void setIndeterminate(boolean indeterminate) { throw new RuntimeException("Stub!"); }
public  android.graphics.drawable.Drawable getIndeterminateDrawable() { throw new RuntimeException("Stub!"); }
public  void setIndeterminateDrawable(android.graphics.drawable.Drawable d) { throw new RuntimeException("Stub!"); }
public  android.graphics.drawable.Drawable getProgressDrawable() { throw new RuntimeException("Stub!"); }
public  void setProgressDrawable(android.graphics.drawable.Drawable d) { throw new RuntimeException("Stub!"); }
protected  boolean verifyDrawable(android.graphics.drawable.Drawable who) { throw new RuntimeException("Stub!"); }
public  void postInvalidate() { throw new RuntimeException("Stub!"); }
public synchronized  void setProgress(int progress) { throw new RuntimeException("Stub!"); }
public synchronized  void setSecondaryProgress(int secondaryProgress) { throw new RuntimeException("Stub!"); }
public synchronized  int getProgress() { throw new RuntimeException("Stub!"); }
public synchronized  int getSecondaryProgress() { throw new RuntimeException("Stub!"); }
public synchronized  int getMax() { throw new RuntimeException("Stub!"); }
public synchronized  void setMax(int max) { throw new RuntimeException("Stub!"); }
public final synchronized  void incrementProgressBy(int diff) { throw new RuntimeException("Stub!"); }
public final synchronized  void incrementSecondaryProgressBy(int diff) { throw new RuntimeException("Stub!"); }
public  void setInterpolator(android.content.Context context, int resID) { throw new RuntimeException("Stub!"); }
public  void setInterpolator(android.view.animation.Interpolator interpolator) { throw new RuntimeException("Stub!"); }
public  android.view.animation.Interpolator getInterpolator() { throw new RuntimeException("Stub!"); }
public  void setVisibility(int v) { throw new RuntimeException("Stub!"); }
protected  void onVisibilityChanged(android.view.View changedView, int visibility) { throw new RuntimeException("Stub!"); }
public  void invalidateDrawable(android.graphics.drawable.Drawable dr) { throw new RuntimeException("Stub!"); }
protected  void onSizeChanged(int w, int h, int oldw, int oldh) { throw new RuntimeException("Stub!"); }
protected synchronized  void onDraw(android.graphics.Canvas canvas) { throw new RuntimeException("Stub!"); }
protected synchronized  void onMeasure(int widthMeasureSpec, int heightMeasureSpec) { throw new RuntimeException("Stub!"); }
protected  void drawableStateChanged() { throw new RuntimeException("Stub!"); }
public  android.os.Parcelable onSaveInstanceState() { throw new RuntimeException("Stub!"); }
public  void onRestoreInstanceState(android.os.Parcelable state) { throw new RuntimeException("Stub!"); }
protected  void onAttachedToWindow() { throw new RuntimeException("Stub!"); }
protected  void onDetachedFromWindow() { throw new RuntimeException("Stub!"); }
}

==> android-4.0.1.2-sources.jar: android/widget/ProgressBar.java <==
package android.widget;
@android.widget.RemoteViews.RemoteView()
public class ProgressBar
  extends android.view.View
{
public  ProgressBar(android.content.Context context) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
public  ProgressBar(android.content.Context context, android.util.AttributeSet attrs) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
public  ProgressBar(android.content.Context context, android.util.AttributeSet attrs, int defStyle) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
public synchronized  boolean isIndeterminate() { throw new RuntimeException("Stub!"); }
public synchronized  void setIndeterminate(boolean indeterminate) { throw new RuntimeException("Stub!"); }
public  android.graphics.drawable.Drawable getIndeterminateDrawable() { throw new RuntimeException("Stub!"); }
public  void setIndeterminateDrawable(android.graphics.drawable.Drawable d) { throw new RuntimeException("Stub!"); }
public  android.graphics.drawable.Drawable getProgressDrawable() { throw new RuntimeException("Stub!"); }
public  void setProgressDrawable(android.graphics.drawable.Drawable d) { throw new RuntimeException("Stub!"); }
protected  boolean verifyDrawable(android.graphics.drawable.Drawable who) { throw new RuntimeException("Stub!"); }
public  void jumpDrawablesToCurrentState() { throw new RuntimeException("Stub!"); }
public  void postInvalidate() { throw new RuntimeException("Stub!"); }
public synchronized  void setProgress(int progress) { throw new RuntimeException("Stub!"); }
public synchronized  void setSecondaryProgress(int secondaryProgress) { throw new RuntimeException("Stub!"); }
public synchronized  int getProgress() { throw new RuntimeException("Stub!"); }
public synchronized  int getSecondaryProgress() { throw new RuntimeException("Stub!"); }
public synchronized  int getMax() { throw new RuntimeException("Stub!"); }
public synchronized  void setMax(int max) { throw new RuntimeException("Stub!"); }
public final synchronized  void incrementProgressBy(int diff) { throw new RuntimeException("Stub!"); }
public final synchronized  void incrementSecondaryProgressBy(int diff) { throw new RuntimeException("Stub!"); }
public  void setInterpolator(android.content.Context context, int resID) { throw new RuntimeException("Stub!"); }
public  void setInterpolator(android.view.animation.Interpolator interpolator) { throw new RuntimeException("Stub!"); }
public  android.view.animation.Interpolator getInterpolator() { throw new RuntimeException("Stub!"); }
public  void setVisibility(int v) { throw new RuntimeException("Stub!"); }
protected  void onVisibilityChanged(android.view.View changedView, int visibility) { throw new RuntimeException("Stub!"); }
public  void invalidateDrawable(android.graphics.drawable.Drawable dr) { throw new RuntimeException("Stub!"); }
protected  void onSizeChanged(int w, int h, int oldw, int oldh) { throw new RuntimeException("Stub!"); }
protected synchronized  void onDraw(android.graphics.Canvas canvas) { throw new RuntimeException("Stub!"); }
protected synchronized  void onMeasure(int widthMeasureSpec, int heightMeasureSpec) { throw new RuntimeException("Stub!"); }
protected  void drawableStateChanged() { throw new RuntimeException("Stub!"); }
public  android.os.Parcelable onSaveInstanceState() { throw new RuntimeException("Stub!"); }
public  void onRestoreInstanceState(android.os.Parcelable state) { throw new RuntimeException("Stub!"); }
protected  void onAttachedToWindow() { throw new RuntimeException("Stub!"); }
protected  void onDetachedFromWindow() { throw new RuntimeException("Stub!"); }
public  void onInitializeAccessibilityEvent(android.view.accessibility.AccessibilityEvent event) { throw new RuntimeException("Stub!"); }
}
